# PortainerEE API (2.39.0)
Download OpenAPI specification:[Download](https://api-docs.portainer.io/versions/ee/2.39.0.yaml)
E-mail:
Portainer API is an HTTP API served by Portainer. It is used by the Portainer UI and everything you can do with the UI can be done using the HTTP API. Examples are available at <https://documentation.portainer.io/api/api-examples/> You can find out more about Portainer at <http://portainer.io> and get some support on [Slack](http://portainer.io/slack/).
